@@ -781,7 +781,7 @@ sub ProcessASF($$;$)
                 $err = 'Invalid ASF object size';
             } elsif ($et->Options('LargeFileSupport')) {
                 if ($et->Options('LargeFileSupport') eq '2') {
-                    $et->WarnOnce('Skipping large ASF object (LargeFileSupport is 2)');
+                    $et->Warn('Skipping large ASF object (LargeFileSupport is 2)');
                 }
                 if ($raf->Seek($size, 1)) {
                     $et->VPrint(0, "  Skipped large ASF object ($size bytes)\n");
@@ -879,7 +879,7 @@ Windows Media Audio (WMA) and Windows Media Video (WMV) files.
 
 =head1 AUTHOR
 
-Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
