@@ -18,7 +18,8 @@
 #               specifying $Image::ExifTool::Geolocation::altDir.  This
 #               database and has entries in the same order as Geolocation.dat,
 #               and each entry is a newline-separated list of alternate names
-#               terminated by a null byte.
+#               terminated by a null byte.  These alternate names are used
+#               only when searching for a city by name (eg. "Big Apple").
 #
 #               Databases are based on data from geonames.org with a
 #               Creative Commons license, reformatted as follows in the
@@ -70,7 +71,7 @@ package Image::ExifTool::Geolocation;
 use strict;
 use vars qw($VERSION $geoDir $altDir $dbInfo);
 
-$VERSION = '1.08';  # (this is the module version number, not the database version)
+$VERSION = '1.09';  # (this is the module version number, not the database version)
 
 my $debug; # set to output processing time for testing
 
@@ -462,7 +463,7 @@ sub GetAltNames($;$)
 sub Geolocate($;$)
 {
     my ($arg, $opts) = @_;
-    my ($city, @exact, %regex, @multiCity, $other, $idx, @cargs, $useLastFound);
+    my ($city, @exact, %regex, @multiCity, $other, $idx, @cargs);
     my ($minPop, $minDistU, $minDistC, @matchParms, @coords, %fcOK, $both);
     my ($pop, $maxDist, $multi, $fcodes, $altNames, @startTime);
 
@@ -509,7 +510,7 @@ sub Geolocate($;$)
             $city = '' unless defined $city;
         } elsif (/^[-+]?\d+(\.\d+)?$/) {    # coordinate format
             push @coords, $_ if @coords < 2;
-        } elsif (/^([-+]?\d*\.\d+) *(([NS])[A-Z]*)? +([-+]?\d*\.\d+) *(([EW])[A-Z]*)?$/i) { # "lat lon" format
+        } elsif (/^([-+]?\d+(?:\.\d+)?) *(([NS])[A-Z]*)? +([-+]?\d+(?:\.\d+)?) *(([EW])[A-Z]*)?/i) { # "lat lon" format
             next if @coords;
             my ($lat, $lon) = ($1, $4);
             $lat = -abs($lat) if $3 and uc($3) eq 'S';
@@ -593,8 +594,16 @@ Entry:  for (; $i<@cityList; ++$i) {
         }
         @startTime and printf("= Processing time: %.3f sec\n", Time::HiRes::tv_interval(\@startTime));
         if (%lastFound) {
-            @coords == 2 and $useLastFound = 1, last; # continue to use coords with last city matches
+            last if @coords == 2;   # continue to use coords with last city matches
             scalar(keys %lastFound) > 200 and warn("Too many matching cities\n"), return();
+            # return nearby cities if "num=" is used and only one match found
+            if ($num > 1 and scalar(keys %lastFound) == 1) {
+                my ($i) = keys %lastFound;
+                my @entry = GetEntry($i);
+                @coords = @entry[8,9];
+                SortDatabase('Latitude');   # (make sure we are sorted by latitude)
+                last;
+            }
             unless (@lastByPop) {
                 @lastByPop = sort { $lastFound{$b} cmp $lastFound{$a} or $cityList[$a] cmp $cityList[$b] } keys %lastFound;
             }
@@ -776,7 +785,7 @@ on the first call.
 
 Sort database in specified order.
 
-    Image::ExifTool::Geolocation::ReadDatabase('City');
+    Image::ExifTool::Geolocation::SortDatabase('City');
 
 =over 4
 
@@ -923,9 +932,10 @@ to the argument list:
               both to determine the closest city matching the specified
               name(s) instead of using GPS only.
 
-   'num=##' - When the search includes GPS coordinates, return the nearest
-              ## cities instead of just the closest one.  Returned cities
-              are in the order from nearest to farthest.
+   'num=##' - When the search includes GPS coordinates, or when a single
+              city is matched by name, return the nearest ## cities instead
+              of just the closest or named one.  Returned cities are in the
+              order from nearest to farthest.
 
 See L<https://exiftool.org/geolocation.html#Read> for more details.
 
@@ -1005,7 +1015,7 @@ the input arguments of the AddEntry method.
 
 =head1 AUTHOR
 
-Copyright 2003-2024, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.  The associated database files are
