@@ -17,7 +17,7 @@ package Image::ExifTool::Validate;
 use strict;
 use vars qw($VERSION %exifSpec);
 
-$VERSION = '1.23';
+$VERSION = '1.24';
 
 use Image::ExifTool qw(:Utils);
 use Image::ExifTool::Exif;
@@ -188,10 +188,10 @@ my %validValue = (
             0x115 => undef,     # SamplesPerPixel
             0x116 => undef,     # RowsPerStrip
             0x117 => undef,     # StripByteCounts
-            0x11a => 'defined $val',        # XResolution
-            0x11b => 'defined $val',        # YResolution
+            # (optional as of 3.0) 0x11a => 'defined $val',        # XResolution
+            # (optional as of 3.0) 0x11b => 'defined $val',        # YResolution
             0x11c => undef,     # PlanarConfiguration
-            0x128 => '$val =~ /^[123]$/',   # ResolutionUnit
+            # (optional as of 3.0) 0x128 => '$val =~ /^[123]$/',   # ResolutionUnit
             0x201 => undef,     # JPEGInterchangeFormat
             0x202 => undef,     # JPEGInterchangeFormatLength
             0x212 => undef,     # YCbCrSubSampling
@@ -218,7 +218,7 @@ my %validValue = (
         ExifIFD => {
             0x9000 => 'defined $val and $val =~ /^\d{4}$/', # ExifVersion
             0x9101 => 'defined $val',       # ComponentsConfiguration
-            0xa000 => 'defined $val',       # FlashpixVersion
+            # (optional as of 3.0) 0xa000 => 'defined $val',       # FlashpixVersion
             0xa001 => '$val == 1 or $val == 0xffff',    # ColorSpace
             0xa002 => 'defined $val',       # PixelXDimension
             0xa003 => 'defined $val',       # PixelYDimension
@@ -421,7 +421,7 @@ sub ValidateExif($$$$$$$$)
 {
     my ($et, $tagTablePtr, $tag, $tagInfo, $lastTag, $ifd, $count, $formatStr) = @_;
 
-    $et->WarnOnce("Entries in $ifd are out of order") if $tag <= $lastTag;
+    $et->Warn("Entries in $ifd are out of order") if $tag <= $lastTag;
 
     # (get tagInfo for unknown tags if Unknown option not used)
     if (not defined $tagInfo and $$tagTablePtr{$tag} and ref $$tagTablePtr{$tag} eq 'HASH') {
@@ -532,8 +532,8 @@ sub ValidateOffsetInfo($$$;$)
         while (@offsets) {
             my $start = pop @offsets;
             my $end = $start + pop @sizes;
-            $et->WarnOnce("$dirName:$$offsets[0]{Name} is zero", $minor) if $start == 0;
-            $et->WarnOnce("$dirName:$$sizes[0]{Name} is zero", $minor) if $start == $end;
+            $et->Warn("$dirName:$$offsets[0]{Name} is zero", $minor) if $start == 0;
+            $et->Warn("$dirName:$$sizes[0]{Name} is zero", $minor) if $start == $end;
             next unless $end > $fileSize;
             if ($start >= $fileSize) {
                 if ($start == 0xffffffff) {
@@ -575,7 +575,7 @@ sub FinishValidate($$)
             # get all tags in this group
             foreach $key (sort keys %{$$et{VALUE}}) {
                 next unless $et->GetGroup($key, 1) eq $grp;
-                next if $$et{TAG_EXTRA}{$key} and $$et{TAG_EXTRA}{$key}{G3}; # ignore sub-documents
+                next if $$et{TAG_EXTRA}{$key}{G3}; # ignore sub-documents
                 # fill in %val lookup with values based on tag ID
                 my $tag = $$et{TAG_INFO}{$key}{TagID};
                 $val{$tag} = $$et{VALUE}{$key};
@@ -678,7 +678,7 @@ ExifTool Validate option is enabled.
 
 =head1 AUTHOR
 
-Copyright 2003-2023, Phil Harvey (philharvey66 at gmail.com)
+Copyright 2003-2025, Phil Harvey (philharvey66 at gmail.com)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
